/*
 Szablon CSS - "Syntetyczny Smok"
 wersja 0.1.4
 Stworzona przez Michala Moroza
 jid: dragonee at chrome.pl
 */

body {
	font-family: verdana, sans-serif, arial;
	color: #533553;
	margin: 0;
	padding: 0;
	background: #fff url(back.jpg) no-repeat top left;
}

a { 
	color: #088;
	text-decoration: none;
}

img {
	border: 0;
}

h1 { 
	font-size: 120%; 
}

pre { 
	font-size: 90%; 
	padding: 5px; 
	border-top: 1px #888 dotted; 
	text-align: left; 
}

textarea, input, fieldset {  
	border: 1px dotted #888;
	text-align: left;
	padding: 1px; 
}

blockquote {
	border-left: 5px solid #383;
	padding: 5px;
	margin: 0 0 10px 15px;
	font-style: italic;
}

blockquote.pullquote {
	float: right;
	margin: 15px;
	width: 160px;
	border-top: 2px solid #7b7;
	border-bottom: 2px solid #7b7;
	border-left: 0;
	padding: 5px;
	font-size: 120%;
	color: #bb8;
	text-align: center;

}

code {
	display: block;
	margin: 10px;
	padding: 2px;
	background-color: #f9fff9;
	border: 1px solid #ddd;
}

#bsmain { 
	min-width: 600px; 
	margin: 5px 0 60px 225px; 
	clear: right; 
}

#bslocal { 
	margin: 0; 
	padding-bottom: 10px; 
	border-top: 1px solid #8a8; 
	border-bottom: 1px solid #8a8; 
}

#foot { 
	clear: both; 
	text-align: right; 
	margin: 0; 
	font-size: 80%; 
	border-top: 1px solid #ccc; 
	background: #f9f9f9 url(bottom.png) no-repeat top right; 
	min-width: 825px; 
	height: 50px; 
	padding-right: 80px;
}

#user { 
	width: 220px; 
	height: 40px; 
	font-size: 125%; 
	border: 1px #666 solid; 
	border-right: 0; 
	background-color: #dfd; 
	margin: 10px 0;
	text-align: center;
	float: right;	
}

#menu { 
	float: left; 
	width: 200px; 
	padding-top: 140px; 
	margin: 25px 15px 30px 10px; 
	border-right: 1px dotted #888; 
	border-bottom: 1px dotted #888;
}

.menuitem { 
	margin-bottom: 12px; 
	padding: 4px; 
	border: 1px solid #888; 
	border-right: 0; 
}

.menuitem:first-line {
	font-size: 110%;
	color: #338833;
}

.items { 
	padding: 10px; 
	text-align: center;
}
.items img {
	padding: 1px;
}

.item { 
	padding: 10px; 
	text-align: right;
}

.entry1, .comment1 { 
	border-left: 2px solid #494;
	padding-left: 8px;	
}

.entry2, .comment2 { 
	border-left: 2px solid #6C6;
	padding-left: 8px;
}
